/*
* Fabric3
* Copyright (c) 2009-2011 Metaform Systems
*
* Fabric3 is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as
* published by the Free Software Foundation, either version 3 of
* the License, or (at your option) any later version, with the
* following exception:
*
* Linking this software statically or dynamically with other
* modules is making a combined work based on this software.
* Thus, the terms and conditions of the GNU General Public
* License cover the whole combination.
*
* As a special exception, the copyright holders of this software
* give you permission to link this software with independent
* modules to produce an executable, regardless of the license
* terms of these independent modules, and to copy and distribute
* the resulting executable under terms of your choice, provided
* that you also meet, for each linked independent module, the
* terms and conditions of the license of that module. An
* independent module is a module which is not derived from or
* based on this software. If you modify this software, you may
* extend this exception to your version of the software, but
* you are not obligated to do so. If you do not wish to do so,
* delete this exception statement from your version.
*
* Fabric3 is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty
* of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
* See the GNU General Public License for more details.
*
* You should have received a copy of the
* GNU General Public License along with Fabric3.
* If not, see <http://www.gnu.org/licenses/>.
*/
package org.fabric3.admin.interpreter.parser;

import org.fabric3.admin.interpreter.Command;
import org.fabric3.admin.interpreter.CommandParser;
import org.fabric3.admin.interpreter.DomainConfiguration;
import org.fabric3.admin.interpreter.ParseException;
import org.fabric3.admin.interpreter.Settings;
import org.fabric3.admin.interpreter.command.UseCommand;
import org.fabric3.admin.interpreter.communication.DomainConnection;

/**
 * @version $Rev: 10072 $ $Date: 2011-03-08 19:08:31 +0000 (Tue, 08 Mar 2011) $
 */
public class UseCommandParser implements CommandParser {
    private DomainConnection domainConnection;
    private Settings settings;

    public UseCommandParser(DomainConnection domainConnection, Settings settings) {
        this.domainConnection = domainConnection;
        this.settings = settings;
    }

    public String getUsage() {
        return "use: Sets the working domain.\n usage: use <domain>";
    }

    public Command parse(String[] tokens) throws ParseException {
        if (tokens.length != 0 && tokens.length != 1) {
            throw new ParseException("Illegal number of arguments");
        }

        if (tokens.length == 0) {
            return new UseCommand(domainConnection);
        } else {
            UseCommand command = new UseCommand(domainConnection);
            String domain = tokens[0];
            DomainConfiguration configuration = settings.getDomainConfiguration(domain);
            if (configuration == null) {
                throw new UnknownDomainException("The domain has not been configured: " + domain);
            }
            command.setAlias(domain);
            command.setAddress(configuration.getAddress());
            command.setUsername(configuration.getUsername());
            command.setPassword(configuration.getPassword());
            return command;
        }
    }

}